/* This file is generated by glib-genmarshal, do not modify it. This code is licensed under the same license as the containing project. Note that it links to GLib, so must comply with the LGPL linking clauses. */
#pragma once

#include <glib-object.h>

G_BEGIN_DECLS

/* VOID:OBJECT (../planner/libplanner/mrp-marshal.list:1) */
#define mrp_marshal_VOID__OBJECT	g_cclosure_marshal_VOID__OBJECT

/* VOID:OBJECT,OBJECT,OBJECT,BOOLEAN (../planner/libplanner/mrp-marshal.list:2) */
extern
void mrp_marshal_VOID__OBJECT_OBJECT_OBJECT_BOOLEAN (GClosure     *closure,
                                                     GValue       *return_value,
                                                     guint         n_param_values,
                                                     const GValue *param_values,
                                                     gpointer      invocation_hint,
                                                     gpointer      marshal_data);

/* VOID:POINTER (../planner/libplanner/mrp-marshal.list:3) */
#define mrp_marshal_VOID__POINTER	g_cclosure_marshal_VOID__POINTER

/* VOID:POINTER,POINTER (../planner/libplanner/mrp-marshal.list:4) */
extern
void mrp_marshal_VOID__POINTER_POINTER (GClosure     *closure,
                                        GValue       *return_value,
                                        guint         n_param_values,
                                        const GValue *param_values,
                                        gpointer      invocation_hint,
                                        gpointer      marshal_data);

/* VOID:OBJECT,INT (../planner/libplanner/mrp-marshal.list:5) */
extern
void mrp_marshal_VOID__OBJECT_INT (GClosure     *closure,
                                   GValue       *return_value,
                                   guint         n_param_values,
                                   const GValue *param_values,
                                   gpointer      invocation_hint,
                                   gpointer      marshal_data);

/* VOID:VOID (../planner/libplanner/mrp-marshal.list:6) */
#define mrp_marshal_VOID__VOID	g_cclosure_marshal_VOID__VOID

/* VOID:BOOLEAN (../planner/libplanner/mrp-marshal.list:7) */
#define mrp_marshal_VOID__BOOLEAN	g_cclosure_marshal_VOID__BOOLEAN

/* VOID:LONG,POINTER (../planner/libplanner/mrp-marshal.list:8) */
extern
void mrp_marshal_VOID__LONG_POINTER (GClosure     *closure,
                                     GValue       *return_value,
                                     guint         n_param_values,
                                     const GValue *param_values,
                                     gpointer      invocation_hint,
                                     gpointer      marshal_data);


G_END_DECLS
